@@ -123,6 +123,10 @@ SenseHandler::SenseHandler( Connection *c, WorldModel *wm, ServerSettings *ss,
   itv.it_value.tv_sec     = 0;
   itv.it_value.tv_usec    = 0;
 #endif
+
+  //*met 8/16/05
+  m_bBusySync = false;
+  m_iSyncCounter = 0;
 }
 
 /*! This is the main routine of this class. It loops forever (till the thread
@@ -203,6 +207,8 @@ bool SenseHandler::analyzeMessage( char *strMsg )
   Log.log( 1, strMsg );
   bool bReturn = false;
   
+  synchronize(); //*met 8/16/05
+
   switch( strMsg[1] )
   {
     case 'c':
@@ -700,9 +706,10 @@ bool SenseHandler::analyzeCoachMessage( char *strMsg )
 bool SenseHandler::analyzeTrainerMessage( char *strMsg )
 {
   Log.log( 605, "received trainer messages: %s" , strMsg );
+  // Currently, a trainer message just resets the episode
   WM->resetEpisode();
-  WM->setMoveSpeed( Parse::parseFirstDouble( &strMsg ) );
 
+  // Put trainer message interpretation code here
   return true;
 }
 
@@ -960,6 +967,100 @@ bool SenseHandler::analyzePlayerParamMessage( char *strMsg )
   return true;
 }
 
+//*met 8/16/05 From Jelle Kok
+/*! This method manipulates the synchronization with the server such
+    that visual information will arrive as early as possible in the
+    cycle. When this method is called for the first time, the view
+    width and quality is set to narrow and low respectively. This to
+    make sure that a visual message is sent by the server at every
+    possible timestep. When in the previous cycle only two message
+    were sent by the server, we know that in the current cycle the
+    first message will appear immediately after the sense
+    message. After this first see message the view cone is set to
+    normal and high. From now on all messages will appear at "0",
+    "50", "no" msec after the arrival of the sense message.
+
+    \return bool indicating whether method returned successfully.
+*/
+bool SenseHandler::synchronize( )
+{
+  // don't sync in synchronization mode
+  if( SS->getSynchMode() == true )
+    return true;
+
+  static Time timeSync         = -1;
+  static bool bNeedSync        = true;
+         char str[64];
+
+  // if in normal play mode -> don't synchronize
+  if( WM->getPlayMode() == PM_PLAY_ON )
+  {
+    m_bBusySync = false;
+    timeSync    = -1;
+    if( WM->getAgentViewQuality() == VQ_LOW )
+    {
+      sprintf( str, "(change_view normal high)" );
+      connection->sendMessage( str );
+      Log.log( 5, "sync: view quality low and play on -> high" );
+      cout << "Debug - change view quality low to high" << endl;
+    }
+  }
+
+  if( bNeedSync == false ) {
+    return false;
+  }
+  else if(  WM->getCurrentTime() > Time( 0, 2 ) &&
+            WM->getPlayMode() != PM_PLAY_ON )
+  {
+    // first call to this method
+    if( m_bBusySync == false )
+    {
+      // if we need synchronization due to late message arrivals, view
+      // frequency is set to 0.5 (narrow low) making it possible to tune
+      // the arrival of see messages such that they will arrive at the
+      // beginning of the cycle.
+
+      Log.logWithTime( 5, "sync: start sync; change freq to 37.5ms");
+      sprintf( str, "(change_view narrow low)" );
+      connection->sendMessage( str );
+      m_bBusySync = true;
+      timeSync    = Time(WM->getCurrentTime().getTime(),
+                         WM->getCurrentTime().getTimeStopped()+ 1 );
+      // +1 to start counting in next cycle
+      return true;
+    }
+
+    // count the number of messages in one cycle; with a frequency of
+    // 37.5, the sequence should be 3, 3, 2. So when 2 messages are
+    // received in the previous cycle we know that we are at the start
+    // of the pattern and are ready.
+    if( timeSync < WM->getCurrentTime() )
+    {
+      if( m_iSeeCounter == 2 )
+      {
+        Log.logWithTime( 5, "sync: received two sees in prev. cycle" );
+        sprintf( str, "(change_view normal high)" );
+	cout << str << endl;
+	cout << WM->getSide() << " " << WM->getPlayerNumber() << " is synch'ed" << endl;
+        connection->sendMessage( str );
+        m_iSyncCounter   = 0;
+        m_bBusySync      = false;
+        bNeedSync        = false;
+        iNrLateMessages  = 0;
+        iNrTotalMessages = 0;
+      }
+      else
+      {
+        Log.logWithTime( 5, " sync:received %d sees in prev. cycle",
+                         m_iSeeCounter );
+        timeSync    = WM->getCurrentTime();
+      }
+    }
+  }
+
+  return true;
+}
+
 /*****************************************************************************/
 /********************* TESTING PURPOSES **************************************/
 /*****************************************************************************/
