@@ -163,12 +163,6 @@ bool WorldModel::coordinateWith( ObjectT obj )
   if( pos.getDistanceTo( getBallPos() ) < 30.0 &&
       pos.getX() > getBallPos().getX() - 5.0 )
   {
-    
-    if( getFastestInSetTo( OBJECT_SET_TEAMMATES, OBJECT_BALL ) ==
-        getAgentObjectType() )
-    {
-      //logCircle( 700, pos, 2.5 ); //gjk
-    }
     Log.log( 700, "coordinate with %d %f %f (%f %f)", 
              obj, pos.getDistanceTo( getBallPos() ),
              pos.getX(), getBallPos().getX(), getBallPos().getY() );
