@@ -136,9 +136,6 @@ int WorldModel::keeperStateVars( double state[] )
   VecPosition C = getKeepawayRect().getPosCenter();
 
   double WB_dist_to_C = getGlobalPosition( PB ).getDistanceTo( C );
-  // WARNING: what's the effect for the keepaway task?
-  if ( getGlobalPosition( PB ).isBehindOf( C ) )
-    WB_dist_to_C *= -1;
   
   int numK = getNumKeepers();
   int numT = getNumTakers();
@@ -162,17 +159,11 @@ int WorldModel::keeperStateVars( double state[] )
   double dist_to_C_K[ numK ];
   for ( int i = 1; i < numK; i++ ) {
     dist_to_C_K[ i ] = getGlobalPosition( K[ i ] ).getDistanceTo( C );
-    // WARNING: what's the effect for the keepaway task?
-    if ( getGlobalPosition( K[ i ] ).isBehindOf( C ) )
-      dist_to_C_K[ i ] *= -1;
   }
 
   double dist_to_C_T[ numT ];
   for ( int i = 0; i < numT; i++ ) {
     dist_to_C_T[ i ] = getGlobalPosition( T[ i ] ).getDistanceTo( C );
-    // WARNING: what's the effect for the keepaway task?
-    if ( getGlobalPosition( T[ i ] ).isBehindOf( C ) )
-      dist_to_C_T[ i ] *= -1;
   }
 
   double nearest_Opp_dist_K[ numK ];
