@@ -107,6 +107,8 @@ int main( int argc, char * argv[] )
   bool     bInfo                             = false;
   bool     bSuppliedLogFile                  = false;
   bool     bSuppliedLogDrawFile              = false;
+  int      iStopAfter                        = -1; //*met+1 8/16/05
+  int      iStartLearningAfter               = -1;
   ofstream os;
   ofstream osDraw;
 
@@ -224,6 +226,14 @@ int main( int argc, char * argv[] )
         case 'w':
 	  strcpy( loadWeightsFile, argv[i+1] );
 	  break;
+        case 'x':
+	  str   = &argv[i+1][0];
+	  iStopAfter = Parse::parseFirstInt( &str ); // exit after running for iStopAfter episodes
+	  break;
+        case 'y':
+	  str   = &argv[i+1][0];
+	  iStartLearningAfter = Parse::parseFirstInt( &str ); // initially don't learn, but turn on learning after iStartLearningAfter episodes have passed
+	  break;
         default:
           cerr << "(main) Unknown command option: " << argv[i] << endl;
       }
@@ -260,18 +270,22 @@ int main( int argc, char * argv[] )
 
   SMDPAgent *sa = NULL;
 
-  int numFeatures = 4 * iNumKeepers + 2 * iNumTakers - 3;
+  double ranges[ MAX_STATE_VARS ];
+  double minValues[ MAX_STATE_VARS ];
+  double resolutions[ MAX_STATE_VARS ];
+  int numFeatures = wm.keeperStateRangesAndResolutions( ranges, minValues, resolutions, 
+							iNumKeepers, iNumTakers );
   int numActions = iNumKeepers;
 
   if ( strlen( strPolicy ) > 0 && strPolicy[0] == 'l' ) {
     // (l)earned
 //     sa = new LearningAgent( numFeatures, numActions,
-// 			    bLearn, loadWeightsFile, saveWeightsFile ); 
+//                          bLearn, loadWeightsFile, saveWeightsFile ); 
   }
   else {
     // (ha)nd (ho)ld (r)andom
     sa = new HandCodedAgent( numFeatures, numActions,
-			     strPolicy );
+			     strPolicy, &wm );
   }
 
   KeepawayPlayer bp( sa, &a, &wm, &ss, &cs, strTeamName, 
@@ -302,8 +316,6 @@ void printOptions( )
 {
   cout << "Command options:"                                         << endl <<
    " a file                - write drawing log info to "             << endl <<
-
-   
    " c(lientconf) file     - use file as client conf file"           << endl <<
    " d(rawloglevel) int[..int] - level(s) of drawing debug info"     << endl <<
    " e(nable) learning 0/1  - turn learning on/off"                  << endl << 
@@ -322,5 +334,7 @@ void printOptions( )
    " r(econnect) int       - reconnect as player nr"                 << endl <<
    " s(erverconf) file     - use file as server conf file"           << endl <<
    " t(eamname) name       - name of your team"                      << endl <<
-   " w(eights) file        - use file to load weights"               << endl;
+   " w(eights) file        - use file to load weights"               << endl <<
+   " x exit after running for this many episodes"                    << endl <<
+   " y enable learning after not learning for this many episodes"    << endl;
 }
